Documentation
¶
Overview ¶
package tap provides a simple TAP (Test Anything Protocol) implementation for Go. It is designed to be used in test code, and provides methods to generate TAP output indicating test results.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Tester ¶
type Tester struct {
// TODO toggles the TODO directive for Ok, Fail, Pass, and similar.
TODO bool
// contains filtered or unexported fields
}
Tester is a type to encapsulate test state. Methods on this type generate TAP output.
func (*Tester) Diagnostic ¶
Diagnostic generates a diagnostic from the message, which may span multiple lines.
func (*Tester) Fail ¶
Fail indicates that a test has failed. This is typically only used when the logic is too complex to fit naturally into an Ok() call.
func (*Tester) Header ¶
Header displays a TAP header including version number and expected number of tests to run.
Click to show internal directories.
Click to hide internal directories.